@@ -1,6 +1,8 @@
 #ifndef LOGSUMEXP_H
 #define LOGSUMEXP_H
 
-#include <RcppArmadillo.h>
+#include "config.h"
+
 double logSumExp(const arma::vec& x);
+
 #endif
